@@ -35,6 +35,10 @@ pub fn read_link(path: &Path) -> io::Result<PathBuf> {
 
 impl TreeLineType {
 
+    pub fn is_pruning(&self) -> bool {
+        matches!(self, Self::Pruning)
+    }
+
     fn resolve(direct_target: &Path) -> io::Result<Self> {
         let mut final_target = direct_target.to_path_buf();
         let mut final_metadata = fs::symlink_metadata(&final_target)?;
@@ -74,7 +78,7 @@ impl TreeLineType {
         })
     }
 
-    pub fn new(path: &Path, ft: &fs::FileType) -> Self {
+    pub fn new(path: &Path, ft: fs::FileType) -> Self {
         if ft.is_dir() {
             Self::Dir
         } else if ft.is_symlink() {
